# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/forex/crypto/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/forex/crypto/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Forex\\Crypto\\": "packages/forex/crypto/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Forex\Crypto\Providers\CryptoServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Crypto'  => Forex\Crypto\Facades\Crypto::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Forex\\CryptoTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Forex\Crypto\Providers\CryptoServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Forex\Crypto\Providers\CryptoServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Forex\Crypto\Providers\CryptoServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/crypto/{modulename}

**User**

    http://path-to-route-folder/user/crypto/{modulename}

**Public**

    http://path-to-route-folder/cryptos


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/crypto/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/crypto/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/crypto/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/crypto/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/crypto/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/crypto/{modulename}/{slug}
    METHOD: GET